Welcome to PyRCN's documentation!
=================================

.. toctree::
   :maxdepth: 1

   introduction
   installation
   usage
   tutorial
   development
   citation

.. toctree::
   :maxdepth: 3
   :caption: Included estimators

   PyRCN/echo_state_network/BaseEchoStateNetwork
   PyRCN/echo_state_network/ESNClassifier
   PyRCN/echo_state_network/ESNRegressor

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Acknowledgements
----------------

This research is funded by the European Social Fund (Application number: 100327771) and co-financed by tax funds based on the budget approved by the members of the Saxon State Parliament, and by Ghent University.

.. image:: logos/SMWA_EFRE-ESF_Sachsen_Logokombi_quer_03.jpg
  :height: 90
  :alt: Europäischer Sozialfonds

.. image:: logos/Logo_IDLab_White.png
  :height: 70
  :alt: IDLab

.. image:: logos/logo_UGent_EN_RGB_2400_color-on-white.png
  :height: 70
  :alt: Ghent University

.. image:: logos/Logo-STKS.jpg
  :height: 70
  :alt: Kognitive Systeme und Sprachtechnologie

.. image:: logos/TUD_Logo_HKS41_114.png
  :height: 70
  :alt: Ghent University
